# run with WISH8.4 using -use x->x_CWindow
#

set chan $argv
frame .top
button .top.chdn -text "CHDN" -command { adjchannel { -1 } }
label .top.chan -textvariable chan
button .top.chup -text "CHUP" -command { adjchannel { 1 } }
pack .top.chdn -side left
pack .top.chan -side left
pack .top.chup -side left
pack .top

proc adjchannel { rel } {
    global chan

    set chan [expr $chan + $rel]
    puts "CHST $chan"
}
